@@ -27,23 +27,11 @@ log = logging.getLogger(__name__)
 
 
 class Application(QtWidgets.QApplication):
-    file_open_signal = QtCore.pyqtSignal(str)
+    file_open_signal = QtCore.Signal(str)
 
-    def __init__(self, argv, hdpi=True):
+    def __init__(self, argv):
 
         self.setStyle(QtWidgets.QStyleFactory.create("Fusion"))
-        # both Qt and PyQt must be version >= 5.6 in order to enable high DPI scaling
-        if parse_version(QtCore.QT_VERSION_STR) >= parse_version("5.6") and parse_version(QtCore.PYQT_VERSION_STR) >= parse_version("5.6"):
-            # only available starting Qt version 5.6
-            if hdpi:
-                if sys.platform.startswith("linux"):
-                    log.warning("HDPI mode is enabled. HDPI support on Linux is not fully stable and GNS3 may crash depending of your version of Linux. To disabled HDPI mode please edit ~/.config/GNS3/gns3_gui.conf and set 'hdpi' to 'false'")
-                self.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling)
-                self.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps)
-            else:
-                log.info("HDPI mode is disabled")
-                self.setAttribute(QtCore.Qt.AA_DisableHighDpiScaling)
-
         super().__init__(argv)
 
         # this is tell Wayland what is the name of the desktop file (gns3.desktop)
@@ -60,7 +48,7 @@ class Application(QtWidgets.QApplication):
         self.open_file_at_startup = None
 
     def event(self, event):
-        # When you double click file you receive an event
+        # When you double click on a file, you receive an event
         # and not the file as command line parameter
         if sys.platform.startswith("darwin"):
             if isinstance(event, QtGui.QFileOpenEvent):
