@@ -19,11 +19,13 @@
 Dialog to configure and update node settings using widget pages.
 """
 
-from ..qt import QtGui
+from ..qt import QtWidgets
 from ..ui.configuration_dialog_ui import Ui_configurationDialog
-from .node_configurator_dialog import ConfigurationError
+from .node_properties_dialog import ConfigurationError
+
+
+class ConfigurationDialog(QtWidgets.QDialog, Ui_configurationDialog):
 
-class ConfigurationDialog(QtGui.QDialog, Ui_configurationDialog):
     """
     Configuration dialog implementation.
 
@@ -35,17 +37,21 @@ class ConfigurationDialog(QtGui.QDialog, Ui_configurationDialog):
 
     def __init__(self, name, settings, configuration_page, parent):
 
-        QtGui.QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
 
         self.uiTitleLabel.setText(name)
         self.setWindowTitle(configuration_page.windowTitle())
         self.uiConfigStackedWidget.addWidget(configuration_page)
         self.uiConfigStackedWidget.setCurrentWidget(configuration_page)
+        self.setModal(True)
         configuration_page.loadSettings(settings)
         self._settings = settings
         self._configuration_page = configuration_page
 
+    def settings(self):
+        return self._settings
+
     def on_uiButtonBox_clicked(self, button):
         """
         Slot called when a button of the uiButtonBox is clicked.
@@ -53,12 +59,11 @@ class ConfigurationDialog(QtGui.QDialog, Ui_configurationDialog):
         :param button: button that was clicked (QAbstractButton)
         """
 
-        if button == self.uiButtonBox.button(QtGui.QDialogButtonBox.Cancel):
-            QtGui.QDialog.reject(self)
+        if button == self.uiButtonBox.button(QtWidgets.QDialogButtonBox.StandardButton.Cancel):
+            QtWidgets.QDialog.reject(self)
         else:
             try:
                 self._configuration_page.saveSettings(self._settings)
             except ConfigurationError:
                 return
-            QtGui.QDialog.accept(self)
-
+            QtWidgets.QDialog.accept(self)
