@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 #
+# Copyright (C) 2019 Pekka Helenius
 # Copyright (C) 2014 GNS3 Technologies Inc.
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,13 +20,14 @@
 Graphical representation of an Ethernet link for QGraphicsScene.
 """
 
-from ..qt import QtCore, QtGui
+from ..qt import QtCore, QtGui, QtWidgets
 from .link_item import LinkItem
-from .note_item import NoteItem
+from .label_item import LabelItem
 from ..ports.port import Port
 
 
 class EthernetLinkItem(LinkItem):
+
     """
     Ethernet link for the scene.
 
@@ -35,12 +37,11 @@ class EthernetLinkItem(LinkItem):
     :param destination_port: destination Port instance
     :param link: Link instance (contains back-end stuff for this link)
     :param adding_flag: indicates if this link is being added (no destination yet)
-    :param multilink: used to draw multiple link between the same source and destination
     """
 
-    def __init__(self, source_item, source_port, destination_item, destination_port, link=None, adding_flag=False, multilink=0):
+    def __init__(self, source_item, source_port, destination_item, destination_port, link=None, adding_flag=False):
 
-        LinkItem.__init__(self, source_item, source_port, destination_item, destination_port, link, adding_flag, multilink)
+        super().__init__(source_item, source_port, destination_item, destination_port, link, adding_flag)
         self._source_collision_offset = 0.0
         self._destination_collision_offset = 0.0
 
@@ -51,10 +52,16 @@ class EthernetLinkItem(LinkItem):
 
         LinkItem.adjust(self)
 
-        if self._hovered:
-            self.setPen(QtGui.QPen(QtCore.Qt.red, self._pen_width + 1, QtCore.Qt.SolidLine, QtCore.Qt.RoundCap, QtCore.Qt.RoundJoin))
-        else:
-            self.setPen(QtGui.QPen(QtCore.Qt.black, self._pen_width, QtCore.Qt.SolidLine, QtCore.Qt.RoundCap, QtCore.Qt.RoundJoin))
+        try:
+            if self._hovered:
+                self.setPen(QtGui.QPen(QtCore.Qt.GlobalColor.red, self._link._link_style["width"] + 1, QtCore.Qt.PenStyle.SolidLine, QtCore.Qt.PenCapStyle.RoundCap, QtCore.Qt.PenJoinStyle.RoundJoin))
+            else:
+                self.setPen(QtGui.QPen(QtGui.QColor(self._link._link_style["color"]), self._link._link_style["width"], self._link._link_style["type"], QtCore.Qt.PenCapStyle.RoundCap, QtCore.Qt.PenJoinStyle.RoundJoin))
+        except:
+            if self._hovered:
+                self.setPen(QtGui.QPen(QtCore.Qt.GlobalColor.red, self._pen_width + 1, QtCore.Qt.PenStyle.SolidLine, QtCore.Qt.PenCapStyle.RoundCap, QtCore.Qt.PenJoinStyle.RoundJoin))
+            else:
+                self.setPen(QtGui.QPen(QtGui.QColor("#000000"), self._pen_width, QtCore.Qt.PenStyle.SolidLine, QtCore.Qt.PenCapStyle.RoundCap, QtCore.Qt.PenJoinStyle.RoundJoin))
 
         # draw a line between nodes
         path = QtGui.QPainterPath(self.source)
@@ -74,7 +81,7 @@ class EthernetLinkItem(LinkItem):
         :returns: QPainterPath instance
         """
 
-        path = QtGui.QGraphicsPathItem.shape(self)
+        path = QtWidgets.QGraphicsPathItem.shape(self)
         offset = self._point_size / 2
         if not self._adding_flag:
             if self.length:
@@ -105,23 +112,26 @@ class EthernetLinkItem(LinkItem):
         :param widget: QWidget instance.
         """
 
-        QtGui.QGraphicsPathItem.paint(self, painter, option, widget)
-        if not self._adding_flag and self._settings["draw_link_status_points"]:
+        QtWidgets.QGraphicsPathItem.paint(self, painter, option, widget)
+        if not self._adding_flag:
 
             # points disappears if nodes are too close to each others.
             if self.length < 100:
                 return
 
-            if self._source_port.status() == Port.started:
+            if self._link.suspended() or self._source_port.status() == Port.suspended:
+                # link or port is suspended
+                color = QtCore.Qt.GlobalColor.yellow
+                shape = QtCore.Qt.PenCapStyle.RoundCap
+            elif self._source_port.status() == Port.started:
                 # port is active
-                color = QtCore.Qt.green
-            elif self._source_port.status() == Port.suspended:
-                # port is suspended
-                color = QtCore.Qt.yellow
+                color = QtCore.Qt.GlobalColor.green
+                shape = QtCore.Qt.PenCapStyle.RoundCap
             else:
-                color = QtCore.Qt.red
+                color = QtCore.Qt.GlobalColor.red
+                shape = QtCore.Qt.PenCapStyle.SquareCap
 
-            painter.setPen(QtGui.QPen(color, self._point_size, QtCore.Qt.SolidLine, QtCore.Qt.RoundCap, QtCore.Qt.MiterJoin))
+            painter.setPen(QtGui.QPen(color, self._point_size, QtCore.Qt.PenStyle.SolidLine, shape, QtCore.Qt.PenJoinStyle.MiterJoin))
             point1 = QtCore.QPointF(self.source + self.edge_offset) + QtCore.QPointF((self.dx * self._source_collision_offset) / self.length, (self.dy * self._source_collision_offset) / self.length)
 
             # avoid any collision of the status point with the source node
@@ -136,36 +146,35 @@ class EthernetLinkItem(LinkItem):
                     self._source_collision_offset -= 10
 
             source_port_label = self._source_port.label()
+
+            if source_port_label is None:
+                source_port_label = LabelItem(self._source_item)
+                source_port_label.setPlainText(self._source_port.shortName())
+                source_port_label.setPos(self.mapToItem(self._source_item, point1))
+                self._source_port.setLabel(source_port_label)
+
             if self._draw_port_labels:
-                if source_port_label is None:
-                    source_port_label = NoteItem(self._source_item)
-                    if not self._source_port.isStub():
-                        source_port_name = self._source_port.name().replace(self._source_port.longNameType(),
-                                                                            self._source_port.shortNameType())
-                    else:
-                        source_port_name = self._source_port.name()
-                    source_port_label.setPlainText(source_port_name)
-                    source_port_label.setPos(self.mapToItem(self._source_item, point1))
-                    self._source_port.setLabel(source_port_label)
-
-                elif source_port_label and not source_port_label.isVisible():
-                    source_port_label.show()
-
-            elif source_port_label:
+                source_port_label.setFlag(QtWidgets.QGraphicsItem.GraphicsItemFlag.ItemIsMovable, not self._source_item.locked())
+                source_port_label.show()
+            else:
                 source_port_label.hide()
 
-            painter.drawPoint(point1)
+            if self._settings["draw_link_status_points"] and self.pen().style() != QtCore.Qt.PenStyle.NoPen:
+                painter.drawPoint(point1)
 
-            if self._destination_port.status() == Port.started:
+            if self._link.suspended() or self._destination_port.status() == Port.suspended:
+                # link or port is suspended
+                color = QtCore.Qt.GlobalColor.yellow
+                shape = QtCore.Qt.PenCapStyle.RoundCap
+            elif self._destination_port.status() == Port.started:
                 # port is active
-                color = QtCore.Qt.green
-            elif self._destination_port.status() == Port.suspended:
-                # port is suspended
-                color = QtCore.Qt.yellow
+                color = QtCore.Qt.GlobalColor.green
+                shape = QtCore.Qt.PenCapStyle.RoundCap
             else:
-                color = QtCore.Qt.red
+                color = QtCore.Qt.GlobalColor.red
+                shape = QtCore.Qt.PenCapStyle.SquareCap
 
-            painter.setPen(QtGui.QPen(color, self._point_size, QtCore.Qt.SolidLine, QtCore.Qt.RoundCap, QtCore.Qt.MiterJoin))
+            painter.setPen(QtGui.QPen(color, self._point_size, QtCore.Qt.PenStyle.SolidLine, shape, QtCore.Qt.PenJoinStyle.MiterJoin))
             point2 = QtCore.QPointF(self.destination - self.edge_offset) - QtCore.QPointF((self.dx * self._destination_collision_offset) / self.length, (self.dy * self._destination_collision_offset) / self.length)
 
             # avoid any collision of the status point with the destination node
@@ -180,22 +189,20 @@ class EthernetLinkItem(LinkItem):
                     self._destination_collision_offset -= 10
 
             destination_port_label = self._destination_port.label()
+
+            if destination_port_label is None:
+                destination_port_label = LabelItem(self._destination_item)
+                destination_port_label.setPlainText(self._destination_port.shortName())
+                destination_port_label.setPos(self.mapToItem(self._destination_item, point2))
+                self._destination_port.setLabel(destination_port_label)
+
             if self._draw_port_labels:
-                if destination_port_label is None:
-                    destination_port_label = NoteItem(self._destination_item)
-                    if not self._destination_port.isStub():
-                        destination_port_name = self._destination_port.name().replace(self._destination_port.longNameType(),
-                                                                                      self._destination_port.shortNameType())
-                    else:
-                        destination_port_name = self._destination_port.name()
-                    destination_port_label.setPlainText(destination_port_name)
-                    destination_port_label.setPos(self.mapToItem(self._destination_item, point2))
-                    self._destination_port.setLabel(destination_port_label)
-
-                elif destination_port_label and not destination_port_label.isVisible():
-                    destination_port_label.show()
-
-            elif destination_port_label:
+                destination_port_label.setFlag(QtWidgets.QGraphicsItem.GraphicsItemFlag.ItemIsMovable, not self._destination_item.locked())
+                destination_port_label.show()
+            else:
                 destination_port_label.hide()
 
-            painter.drawPoint(point2)
+            if self._settings["draw_link_status_points"] and self.pen().style() != QtCore.Qt.PenStyle.NoPen:
+                painter.drawPoint(point2)
+
+        self._drawSymbol()
