@@ -19,21 +19,18 @@
 Wizard for IOS routers.
 """
 
-import sys
 import os
 import re
 
-from gns3.qt import QtCore, QtGui
-from gns3.servers import Servers
-from gns3.node import Node
-from gns3.utils.message_box import MessageBox
-from gns3.utils.run_in_terminal import RunInTerminal
-from gns3.utils.get_resource import get_resource
-from gns3.utils.get_default_base_config import get_default_base_config
 
-from ....settings import ENABLE_CLOUD
+from gns3.qt import QtCore, QtGui, QtWidgets, qslot
+from gns3.node import Node
+from gns3.utils.run_in_terminal import RunInTerminal
+from gns3.dialogs.vm_with_images_wizard import VMWithImagesWizard
+from gns3.controller import Controller
+
 from ..ui.ios_router_wizard_ui import Ui_IOSRouterWizard
-from ..settings import PLATFORMS_DEFAULT_RAM, CHASSIS, ADAPTER_MATRIX, WIC_MATRIX
+from ..settings import PLATFORMS_DEFAULT_RAM, PLATFORMS_DEFAULT_NVRAM, CHASSIS, ADAPTER_MATRIX, WIC_MATRIX
 from .. import Dynamips
 from ..nodes.c1700 import C1700
 from ..nodes.c2600 import C2600
@@ -53,8 +50,11 @@ PLATFORM_TO_CLASS = {
     "c7200": C7200
 }
 
+import logging
+log = logging.getLogger(__name__)
 
-class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
+
+class IOSRouterWizard(VMWithImagesWizard, Ui_IOSRouterWizard):
     """
     Wizard to create an IOS router.
 
@@ -64,41 +64,37 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
 
     def __init__(self, ios_routers, parent):
 
-        QtGui.QWizard.__init__(self, parent)
-        self.setupUi(self)
-        self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/symbols/router.normal.svg"))
-        self.setWizardStyle(QtGui.QWizard.ModernStyle)
-        if sys.platform.startswith("darwin"):
-            # we want to see the cancel button on OSX
-            self.setOptions(QtGui.QWizard.NoDefaultButton)
+        super().__init__(ios_routers, parent)
+        self.setPixmap(QtWidgets.QWizard.WizardPixmap.LogoPixmap, QtGui.QPixmap(":/symbols/router.svg"))
 
-        self.uiRemoteRadioButton.toggled.connect(self._remoteServerToggledSlot)
-        self.uiLoadBalanceCheckBox.toggled.connect(self._loadBalanceToggledSlot)
-        self.uiIOSImageToolButton.clicked.connect(self._iosImageBrowserSlot)
         self.uiTestIOSImagePushButton.clicked.connect(self._testIOSImageSlot)
         self.uiIdlePCFinderPushButton.clicked.connect(self._idlePCFinderSlot)
         self.uiEtherSwitchCheckBox.stateChanged.connect(self._etherSwitchSlot)
         self.uiPlatformComboBox.currentIndexChanged[str].connect(self._platformChangedSlot)
         self.uiPlatformComboBox.addItems(list(PLATFORMS_DEFAULT_RAM.keys()))
 
+        self._router = None
         # Validate the Idle PC value
         self._idle_valid = False
-        idle_pc_rgx = QtCore.QRegExp("^(0x[0-9a-fA-F]+)?$")
-        validator = QtGui.QRegExpValidator(idle_pc_rgx)
+
+        # True if we have create a temporary project for computing IDLE PC
+        self._project_created = False
+
+        idle_pc_rgx = QtCore.QRegularExpression("^(0x[0-9a-fA-F]{8})?$")
+        validator = QtGui.QRegularExpressionValidator(idle_pc_rgx, self)
         self.uiIdlepcLineEdit.setValidator(validator)
         self.uiIdlepcLineEdit.textChanged.connect(self._idlePCValidateSlot)
         self.uiIdlepcLineEdit.textChanged.emit(self.uiIdlepcLineEdit.text())
 
         # location of the base config templates
-        self._base_startup_config_template = get_resource(os.path.join("configs", "ios_base_startup-config.txt"))
-        self._base_private_config_template = get_resource(os.path.join("configs", "ios_base_private-config.txt"))
-        self._base_etherswitch_startup_config_template = get_resource(os.path.join("configs", "ios_etherswitch_startup-config.txt"))
+        self._base_startup_config_template = "ios_base_startup-config.txt"
+        self._base_etherswitch_startup_config_template = "ios_etherswitch_startup-config.txt"
 
-        #FIXME: hide because of issue on Windows.
+        # FIXME: hide because of issue on Windows.
         self.uiTestIOSImagePushButton.hide()
 
         # Mandatory fields
-        self.uiNamePlatformWizardPage.registerField("name*", self.uiNameLineEdit)
+        self.uiNameWizardPage.registerField("name*", self.uiNameLineEdit)
         self.uiIOSImageWizardPage.registerField("image*", self.uiIOSImageLineEdit)
 
         self._widget_slots = {0: self.uiSlot0comboBox,
@@ -113,38 +109,51 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
                              1: self.uiWic1comboBox,
                              2: self.uiWic2comboBox}
 
-        self._ios_routers = ios_routers
+        from ..pages.ios_router_preferences_page import IOSRouterPreferencesPage
+        self.addImageSelector(self.uiIOSExistingImageRadioButton,
+                              self.uiIOSImageListComboBox,
+                              self.uiIOSImageLineEdit,
+                              self.uiIOSImageToolButton,
+                              IOSRouterPreferencesPage.getIOSImage)
 
-        if Dynamips.instance().settings()["use_local_server"]:
-            # skip the server page if we use the local server
-            self.setStartId(1)
-
-        if not ENABLE_CLOUD:
-            self.uiCloudRadioButton.hide()
-
-    def _remoteServerToggledSlot(self, checked):
+    def _prefillPlatform(self):
         """
-        Slot for when the remote server radio button is toggled.
-
-        :param checked: either the button is checked or not
+        Try to guess the platform based on image name
         """
 
-        if checked:
-            self.uiRemoteServersGroupBox.setEnabled(True)
-        else:
-            self.uiRemoteServersGroupBox.setEnabled(False)
+        # try to guess the platform
+        image = os.path.basename(self.uiIOSImageLineEdit.text())
+        match = re.match(r"^(c[0-9]+)p?-\w+", image.lower())
+        if not match:
+            QtWidgets.QMessageBox.warning(self, "IOS image", "Could not detect the platform, make sure this is a valid IOS image!")
+            return
 
-    def _loadBalanceToggledSlot(self, checked):
-        """
-        Slot for when the load balance checkbox is toggled.
+        detected_platform = match.group(1)
+        detected_chassis = ""
+        # IOS images for the 3600 platform start with the chassis name (c3620 etc.)
+        for platform, chassis in CHASSIS.items():
+            if detected_platform[1:] in chassis:
+                detected_chassis = detected_platform[1:]
+                detected_platform = platform
+                break
 
-        :param checked: either the box is checked or not
-        """
+        if detected_platform not in PLATFORMS_DEFAULT_RAM:
+            QtWidgets.QMessageBox.warning(self, "IOS image", "This IOS image is for the {} platform/chassis and is not supported by this application!".format(detected_platform))
+            return
 
-        if checked:
-            self.uiRemoteServersComboBox.setEnabled(False)
-        else:
-            self.uiRemoteServersComboBox.setEnabled(True)
+        if image.lower().startswith("c7200p"):
+            QtWidgets.QMessageBox.warning(self, "IOS image", "This IOS image is for c7200 PowerPC routers and is not recommended. Please use an IOS image that do not start with c7200p.")
+
+        if image.lower().startswith("c1700") or image.lower().startswith("c2600"):
+            QtWidgets.QMessageBox.warning(self, "IOS image", "Using c1700 or c2600 IOS images is not recommended, they can be unstable or buggy")
+
+        index = self.uiPlatformComboBox.findText(detected_platform)
+        if index != -1:
+            self.uiPlatformComboBox.setCurrentIndex(index)
+
+        index = self.uiChassisComboBox.findText(detected_chassis)
+        if index != -1:
+            self.uiChassisComboBox.setCurrentIndex(index)
 
     def _platformChangedSlot(self, platform):
         """
@@ -170,9 +179,9 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         platform = self.uiPlatformComboBox.currentText()
         ram = self.uiRamSpinBox.value()
         ios_image = self.uiIOSImageLineEdit.text()
-        dynamips = os.path.realpath(Dynamips.instance().settings()["path"])
+        dynamips = os.path.realpath(Dynamips.instance().settings()["image"])
         if not os.path.exists(dynamips):
-            QtGui.QMessageBox.critical(self, "IOS image", "Could not find Dynamips executable: {}".format(dynamips))
+            QtWidgets.QMessageBox.critical(self, "IOS image", "Could not find Dynamips executable: {}".format(dynamips))
             return
         command = '"{path}" -P {platform} -r {ram} "{ios_image}"'.format(path=dynamips,
                                                                          platform=platform[1:],
@@ -181,40 +190,42 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         try:
             RunInTerminal(command)
         except OSError as e:
-            QtGui.QMessageBox.critical(self, "IOS image", "Could not test the IOS image: {}".format(e))
+            QtWidgets.QMessageBox.critical(self, "IOS image", "Could not test the IOS image: {}".format(e))
 
     def _idlePCValidateSlot(self):
         """
         Slot to validate the entered Idle-PC Value
         """
-        sender = self.sender()
-        validator = sender.validator()
-        state = validator.validate(sender.text(), 0)[0]
-        if state == QtGui.QValidator.Acceptable:
+
+        validator = self.uiIdlepcLineEdit.validator()
+        text_input = self.uiIdlepcLineEdit.text()
+        state = validator.validate(text_input, len(text_input))[0]
+        if state == QtGui.QValidator.State.Acceptable:
             color = '#A2C964'  # green
             self._idle_valid = True
-        elif state == QtGui.QValidator.Intermediate:
+        elif state == QtGui.QValidator.State.Intermediate:
             color = '#fff79a'  # yellow
             self._idle_valid = False
         else:
             color = '#f6989d'  # red
             self._idle_valid = False
-        sender.setStyleSheet('QLineEdit { background-color: %s }' % color)
+        self.uiIdlepcLineEdit.setStyleSheet('QLineEdit { background-color: %s }' % color)
 
-    def _idlePCFinderSlot(self):
+    def _idlePCFinderSlot(self, ):
         """
         Slot for the idle-PC finder.
         """
-
-        server = Servers.instance().localServer()
-        module = Dynamips.instance()
+        image = self.uiIOSImageLineEdit.text()
         platform = self.uiPlatformComboBox.currentText()
-        ios_image = self.uiIOSImageLineEdit.text()
         ram = self.uiRamSpinBox.value()
-        router_class = PLATFORM_TO_CLASS[platform]
-        self._router = router_class(module, server)
-        self._router.setup(ios_image, ram, name="AUTOIDLEPC")
-        self._router.created_signal.connect(self.createdSlot)
+        Controller.instance().postCompute("/auto_idlepc",
+                                          self._compute_id,
+                                          self._computeAutoIdlepcCallback,
+                                          timeout=None,
+                                          body={
+                                              "image": image,
+                                              "platform": platform,
+                                              "ram": ram})
         self.uiIdlePCFinderPushButton.setEnabled(False)
 
     def _etherSwitchSlot(self, state):
@@ -226,25 +237,23 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         if state:
             # forces the name to EtherSwitch
             self.uiNameLineEdit.setText("EtherSwitch router")
-            #self.uiNameLineEdit.setEnabled(False)
+            # self.uiNameLineEdit.setEnabled(False)
         else:
             self.uiNameLineEdit.setText(self.uiPlatformComboBox.currentText())
-            #self.uiNameLineEdit.setEnabled(True)
+            # self.uiNameLineEdit.setEnabled(True)
 
-    def createdSlot(self, node_id):
+    def serverErrorSlot(self, base_node_id, message):
         """
-        The node for the auto Idle-PC has been created.
+        The auto idle-pc node could not be created.
 
-        :param node_id: not used
+        :param base_node_id: not used
+        :param message: error message from the server.
         """
 
-        self._router.computeAutoIdlepc(self._computeAutoIdlepcCallback)
-        self._auto_idlepc_progress_dialog = QtGui.QProgressDialog("Searching for an Idle-PC value...", "Cancel", 0, 0, parent=self)
-        self._auto_idlepc_progress_dialog.setWindowModality(QtCore.Qt.WindowModal)
-        self._auto_idlepc_progress_dialog.setWindowTitle("Idle-PC finder")
-        self._auto_idlepc_progress_dialog.show()
+        QtWidgets.QMessageBox.critical(self, "Idle-PC finder", "Could not create IOS router: {}".format(message))
 
-    def _computeAutoIdlepcCallback(self, result, error=False):
+    @qslot
+    def _computeAutoIdlepcCallback(self, result, error=False, *args, **kwargs):
         """
         Callback for computeAutoIdlepc.
 
@@ -252,62 +261,18 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         :param error: indicates an error (boolean)
         """
 
-        self._router.delete()
-        if self._auto_idlepc_progress_dialog.wasCanceled():
-            return
-        self._auto_idlepc_progress_dialog.accept()
-
         if error:
-            QtGui.QMessageBox.critical(self, "Idle-PC finder", "Error: ".format(result["message"]))
+            QtWidgets.QMessageBox.critical(self, "Idle-PC finder", "Error: {}".format(result["message"]))
         else:
-            if result["idlepc"] and result["idlepc"] != "0x0":
-                self.uiIdlepcLineEdit.setText(result["idlepc"])
-            else:
-                logs = "\n".join(result["logs"])
-                MessageBox(self, "Idle-PC finder", "Could not find an Idle-PC value", details=logs)
+            idlepc = result["idlepc"]
+            self.uiIdlepcLineEdit.setText(idlepc)
+            QtWidgets.QMessageBox.information(self, "Idle-PC finder", "Idle-PC value {} has been found suitable for your IOS image".format(idlepc))
 
-    def _iosImageBrowserSlot(self):
-        """
-        Slot to open a file browser and select an IOU image.
-        """
+    def done(self, result):
 
-        from ..pages.ios_router_preferences_page import IOSRouterPreferencesPage
-        path = IOSRouterPreferencesPage.getIOSImage(self)
-        if not path:
-            return
-        self.uiIOSImageLineEdit.clear()
-        self.uiIOSImageLineEdit.setText(path)
-
-        # try to guess the platform
-        image = os.path.basename(path)
-        match = re.match("^(c[0-9]+)p?\\-\w+", image.lower())
-        if not match:
-            QtGui.QMessageBox.warning(self, "IOS image", "Could not detect the platform, make sure this is a valid IOS image!")
-            return
-
-        detected_platform = match.group(1)
-        detected_chassis = ""
-        # IOS images for the 3600 platform start with the chassis name (c3620 etc.)
-        for platform, chassis in CHASSIS.items():
-            if detected_platform[1:] in chassis:
-                detected_chassis = detected_platform[1:]
-                detected_platform = platform
-                break
-
-        if detected_platform not in PLATFORMS_DEFAULT_RAM:
-            QtGui.QMessageBox.warning(self, "IOS image", "This IOS image is for the {} platform/chassis and is not supported by this application!".format(detected_platform))
-            return
-
-        if image.lower().startswith("c7200p"):
-            QtGui.QMessageBox.warning(self, "IOS image", "This IOS image is for c7200 PowerPC routers and is not recommended. Please use an IOS image that do not start with c7200p.")
-
-        index = self.uiPlatformComboBox.findText(detected_platform)
-        if index != -1:
-            self.uiPlatformComboBox.setCurrentIndex(index)
-
-        index = self.uiChassisComboBox.findText(detected_chassis)
-        if index != -1:
-            self.uiChassisComboBox.setCurrentIndex(index)
+        if self._router:
+            self._router.delete()
+        super().done(result)
 
     def _populateAdapters(self, platform, chassis):
         """
@@ -326,7 +291,7 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         for slot_number, slot_adapters in ADAPTER_MATRIX[platform][chassis].items():
             self._widget_slots[slot_number].setEnabled(True)
 
-            if type(slot_adapters) == str:
+            if isinstance(slot_adapters, str):
                 # only one default adapter for this slot.
                 self._widget_slots[slot_number].addItem(slot_adapters)
             else:
@@ -348,16 +313,15 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
 
     def initializePage(self, page_id):
 
-        if self.page(page_id) == self.uiServerWizardPage:
-            self.uiRemoteServersComboBox.clear()
-            for server in Servers.instance().remoteServers().values():
-                self.uiRemoteServersComboBox.addItem("{}:{}".format(server.host, server.port), server)
+        super().initializePage(page_id)
 
-        elif self.page(page_id) == self.uiNamePlatformWizardPage:
+        if self.page(page_id) == self.uiIOSImageWizardPage:
+            self.loadImagesList("/dynamips/images")
+        elif self.page(page_id) == self.uiNameWizardPage:
+            self._prefillPlatform()
             self.uiNameLineEdit.setText(self.uiPlatformComboBox.currentText())
             ios_image = self.uiIOSImageLineEdit.text()
             self.setWindowTitle("New IOS router - {}".format(os.path.basename(ios_image)))
-
         elif self.page(page_id) == self.uiMemoryWizardPage:
             # set the correct amount of RAM based on the platform
             from ..pages.ios_router_preferences_page import IOSRouterPreferencesPage
@@ -383,28 +347,28 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
             if self.uiEtherSwitchCheckBox.isChecked():
                 self.uiSlot1comboBox.setCurrentIndex(self.uiSlot1comboBox.findText("NM-16ESW"))
 
+        elif self.page(page_id) == self.uiIdlePCWizardPage:
+            path = self.uiIOSImageLineEdit.text()
+            idle_pc = Dynamips.getDefaultIdlePC(path)
+            if idle_pc is not None:
+                self.uiIdlepcLineEdit.setText(idle_pc)
+
     def validateCurrentPage(self):
         """
         Validates the IOS name and checks validation state for Idle-PC value
         """
 
-        if self.currentPage() == self.uiNamePlatformWizardPage:
-            name = self.uiNameLineEdit.text()
-            for ios_router in self._ios_routers.values():
-                if ios_router["name"] == name:
-                    QtGui.QMessageBox.critical(self, "Name", "{} is already used, please choose another name".format(name))
-                    return False
-                #if self.uiEtherSwitchCheckBox.isChecked() and ios_router["etherswitch"]:
-                #    QtGui.QMessageBox.critical(self, "EtherSwitch router", "A router has already been configured to be used as the EtherSwitch router".format(name))
-                #    return False
+        if super().validateCurrentPage() is False:
+            return False
+
+        if self.currentPage() == self.uiMemoryWizardPage and self.uiPlatformComboBox.currentText() == "c7200":
+            if self.uiRamSpinBox.value() > 512:
+                QtWidgets.QMessageBox.critical(self, "c7200 RAM requirement", "c7200 routers with NPE-400 are limited to 512MB of RAM")
+                return False
         if self.currentPage() == self.uiIdlePCWizardPage:
             if not self._idle_valid:
                 idle_pc = self.uiIdlepcLineEdit.text()
-                QtGui.QMessageBox.critical(self, "Idle-PC", "{} is not a valid Idle-PC value ".format(idle_pc))
-                return False
-        if self.currentPage() == self.uiServerWizardPage and self.uiRemoteRadioButton.isChecked():
-            if not Servers.instance().remoteServers():
-                QtGui.QMessageBox.critical(self, "Remote server", "There is no remote server registered in Dynamips preferences")
+                QtWidgets.QMessageBox.critical(self, "Idle-PC", "{} is not a valid Idle-PC value ".format(idle_pc))
                 return False
         return True
 
@@ -415,39 +379,35 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
         :return: settings dict
         """
 
-        path = self.uiIOSImageLineEdit.text()
-        image = os.path.basename(path)
-        if Dynamips.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked():
-            server = "local"
-        elif self.uiRemoteRadioButton.isChecked():
-            if self.uiLoadBalanceCheckBox.isChecked():
-                server = next(iter(Servers.instance()))
-                server = "{}:{}".format(server.host, server.port)
-            else:
-                server = self.uiRemoteServersComboBox.currentText()
-        else: # Cloud is selected
-            server = "cloud"
+        image = self.uiIOSImageLineEdit.text()
 
+        platform = self.uiPlatformComboBox.currentText()
         settings = {
             "name": self.uiNameLineEdit.text(),
-            "path": path,
-            "startup_config": get_default_base_config(self._base_startup_config_template),
-            "private_config": get_default_base_config(self._base_private_config_template),
-            "ram": self.uiRamSpinBox.value(),
-            "idlepc": self.uiIdlepcLineEdit.text(),
             "image": image,
-            "platform": self.uiPlatformComboBox.currentText(),
-            "chassis": self.uiChassisComboBox.currentText(),
-            "server": server,
+            "startup_config": self._base_startup_config_template,
+            "ram": self.uiRamSpinBox.value(),
+            "nvram": PLATFORMS_DEFAULT_NVRAM[platform],
+            "idlepc": self.uiIdlepcLineEdit.text(),
+            "platform": platform,
+            "compute_id": self._compute_id,
         }
 
-        if self.uiEtherSwitchCheckBox.isChecked():
-            settings["startup_config"] = get_default_base_config(self._base_etherswitch_startup_config_template)
-            settings["default_symbol"] = ":/symbols/multilayer_switch.normal.svg"
-            settings["hover_symbol"] = ":/symbols/multilayer_switch.selected.svg"
-            settings["category"] = Node.switches
+        chassis = self.uiChassisComboBox.currentText()
+        if chassis:
+            settings["chassis"] = chassis
 
-        if image.lower().startswith("c7200p"):
+        if self.uiEtherSwitchCheckBox.isChecked():
+            settings["default_name_format"] = "ESW{0}"
+            settings["startup_config"] = self._base_etherswitch_startup_config_template
+            settings["symbol"] = ":/symbols/multilayer_switch.svg"
+            settings["disk0"] = 1  # adds 1MB disk to store vlan.dat
+            settings["category"] = Node.switches
+        else:
+            settings["auto_delete_disks"] = True
+
+        image_file = os.path.basename(image)
+        if image_file.lower().startswith("c7200p"):
             settings["npe"] = "npe-g2"
 
         for slot_id, widget in self._widget_slots.items():
@@ -471,4 +431,4 @@ class IOSRouterWizard(QtGui.QWizard, Ui_IOSRouterWizard):
             if platform not in WIC_MATRIX:
                 # skip the WIC modules page if the platform doesn't support any.
                 return self.uiNetworkAdaptersWizardPage.nextId() + 1
-        return QtGui.QWizard.nextId(self)
+        return QtWidgets.QWizard.nextId(self)
