@@ -21,78 +21,26 @@ Default Dynamips settings.
 
 from gns3.node import Node
 
-import sys
-import os
-
-
-# default path to Dynamips executable
-if sys.platform.startswith("win"):
-    DEFAULT_DYNAMIPS_PATH = r"dynamips\dynamips.exe"
-elif sys.platform.startswith("darwin") and hasattr(sys, "frozen"):
-    DEFAULT_DYNAMIPS_PATH = os.path.join(os.getcwd(), "dynamips")
-else:
-    paths = [os.getcwd()] + os.environ["PATH"].split(os.pathsep)
-    # look for dynamips in the current working directory and $PATH
-    DEFAULT_DYNAMIPS_PATH = "dynamips"
-    for path in paths:
-        try:
-            if "dynamips" in os.listdir(path) and os.access(os.path.join(path, "dynamips"), os.X_OK):
-                DEFAULT_DYNAMIPS_PATH = os.path.join(path, "dynamips")
-                break
-        except OSError:
-            continue
-
 DYNAMIPS_SETTINGS = {
-    "path": DEFAULT_DYNAMIPS_PATH,
-    "hypervisor_start_port_range": 7200,
-    "hypervisor_end_port_range": 7700,
-    "console_start_port_range": 2001,
-    "console_end_port_range": 2500,
-    "aux_start_port_range": 2501,
-    "aux_end_port_range": 3000,
-    "udp_start_port_range": 10001,
-    "udp_end_port_range": 20000,
-    "use_local_server": True,
-    "allocate_hypervisor_per_device": True,
-    "memory_usage_limit_per_hypervisor": 1024,
-    "allocate_hypervisor_per_ios_image": True,
+    "dynamips_path": "",
+    "allocate_aux_console_ports": False,
     "ghost_ios_support": True,
-    "jit_sharing_support": False,
     "sparse_memory_support": True,
     "mmap_support": True,
 }
 
-DYNAMIPS_SETTING_TYPES = {
-    "path": str,
-    "hypervisor_start_port_range": int,
-    "hypervisor_end_port_range": int,
-    "console_start_port_range": int,
-    "console_end_port_range": int,
-    "aux_start_port_range": int,
-    "aux_end_port_range": int,
-    "udp_start_port_range": int,
-    "udp_end_port_range": int,
-    "use_local_server": bool,
-    "allocate_hypervisor_per_device": bool,
-    "memory_usage_limit_per_hypervisor": int,
-    "allocate_hypervisor_per_ios_image": bool,
-    "ghost_ios_support": bool,
-    "jit_sharing_support": bool,
-    "sparse_memory_support": bool,
-    "mmap_support": bool,
-}
-
 IOS_ROUTER_SETTINGS = {
     "name": "",
-    "path": "",
+    "default_name_format": "R{0}",
+    "usage": "",
     "image": "",
-    "default_symbol": ":/symbols/router.normal.svg",
-    "hover_symbol": ":/symbols/router.selected.svg",
+    "symbol": ":/symbols/router.svg",
     "category": Node.routers,
     "startup_config": "",
     "private_config": "",
+    "console_type": "telnet",
+    "console_auto_start": False,
     "platform": "",
-    "chassis": "",
     "idlepc": "",
     "idlemax": 500,
     "idlesleep": 30,
@@ -100,51 +48,52 @@ IOS_ROUTER_SETTINGS = {
     "mmap": True,
     "sparsemem": True,
     "ram": 128,
-    "nvram": 256,
+    "nvram": 128,
     "mac_addr": "",
-    "disk0": 1,
+    "disk0": 0,
     "disk1": 0,
-    "confreg": "0x2102",
+    "auto_delete_disks": False,
     "system_id": "FTX0945W0MY",
-    "server": "local"
-}
-
-IOS_ROUTER_SETTING_TYPES = {
-    "name": str,
-    "path": str,
-    "image": str,
-    "default_symbol": str,
-    "hover_symbol": str,
-    "category": int,
-    "startup_config": str,
-    "private_config": str,
-    "platform": str,
-    "chassis": str,
-    "idlepc": str,
-    "idlemax": int,
-    "idlesleep": int,
-    "exec_area": int,
-    "mmap": bool,
-    "sparsemem": bool,
-    "ram": int,
-    "nvram": int,
-    "mac_addr": str,
-    "disk0": int,
-    "disk1": int,
-    "confreg": str,
-    "system_id": str,
-    "server": str
+    "compute_id": "local",
+    "node_type": "dynamips"
 }
 
 # supported platforms with the default RAM value
-PLATFORMS_DEFAULT_RAM = {"c1700": 128,
-                         "c2600": 128,
+PLATFORMS_DEFAULT_RAM = {"c1700": 160,
+                         "c2600": 160,
                          "c2691": 192,
                          "c3600": 192,
                          "c3725": 128,
                          "c3745": 256,
                          "c7200": 512}
 
+# supported platforms with the default NVRAM value
+PLATFORMS_DEFAULT_NVRAM = {"c1700": 128,
+                           "c2600": 128,
+                           "c2691": 256,
+                           "c3600": 256,
+                           "c3725": 256,
+                           "c3745": 256,
+                           "c7200": 512}
+
+# MD5 checksum done on uncompressed IOS images
+DEFAULT_IDLEPC = {"7f4ae12a098391bc0edcaf4f44caaf9d": "0x80358a60",  # c1700-adventerprisek9-mz.124-25d
+                  "3aaecd2222e812c16c211bc9f7c77512": "0x824a4dc4",  # c1700-adventerprisek9-mz.124-15.T14
+                  "062a32e9e3f59aeec930ea5694fda9c9": "0x80519c48",  # c2600-adventerprisek9-mz.124-25d
+                  "483e3a579a5144ec23f2f160d4b0c0e2": "0x8027ec88",  # c2600-adventerprisek9-mz.124-15.T14
+                  "37b444b29191630e5b688f002de2171c": "0x603a8bac",  # c3620-a3jk8s-mz.122-26c
+                  "493c4ef6578801d74d715e7d11596964": "0x6050b114",  # c3640-a3js-mz.124-25d
+                  "b88ee1b2ed182737395db2df27f34a33": "0x606071f8",  # c3660-a3jk9s-mz.124-25d
+                  "daed99f508fd42dbaacf711e560643ed": "0x6076e0b4",  # c3660-a3jk9s-mz.124-15.T14
+                  "8dc8486065de63883f29c85825a2f18c": "0x60a48cb8",  # c2691-adventerprisek9-mz.124-25d
+                  "e7ee5a4a57ed1433e5f73ba6e7695c90": "0x60bcf9f8",  # c2691-adventerprisek9-mz.124-15.T14
+                  "606484061b9e52e71d4f4ddab9af19e7": "0x602467a4",  # c3725-adventerprisek9-mz.124-25d
+                  "64f8c427ed48fd21bd02cf1ff254c4eb": "0x60c09aa0",  # c3725-adventerprisek9-mz.124-15.T14
+                  "ddbaf74274822b50fa9670e10c75b08f": "0x60aa1da0",  # c3745-adventerprisek9-mz.124-25d
+                  "4af2e752220ed1397924150ff7bbe4ce": "0x602701e4",  # c3745-adventerprisek9-mz.124-15.T14
+                  "6b89d0d804e1f2bb5b8bda66b5692047": "0x606df838",  # c7200-adventerprisek9-mz.124-24.T5
+                  "dda82f22a39215bc6b27af891e12b8f6": "0x6018c294"}  # c7200-adventerprisek9-mz.155-2.XB
+
 # platforms with supported chassis
 CHASSIS = {"c1700": ("1720", "1721", "1750", "1751", "1760"),
            "c2600": ("2610", "2611", "2620", "2621", "2610XM", "2611XM", "2620XM", "2621XM", "2650XM", "2651XM"),
@@ -191,7 +140,7 @@ C7200_PAS = (
 IO_C7200 = ("C7200-IO-FE",
             "C7200-IO-2FE",
             "C7200-IO-GE-E"
-)
+            )
 
 """
 Build the adapter compatibility matrix:
