@@ -725,6 +725,9 @@ class Node(BaseNode):
             if "console_type" in self.settings():
                 console_type = self.consoleType()
 
+        if aux is False and self.bringToFront() is True:
+            return
+
         if console_type == "telnet":
             from .telnet_console import nodeTelnetConsole
             nodeTelnetConsole(self, console_port, command)
@@ -748,7 +751,7 @@ class Node(BaseNode):
                 if wmctrl_path:
                     try:
                         # use wmctrl to raise the window based on the node name (this doesn't work well with window having multiple tabs)
-                        subprocess.run([wmctrl_path, "-a", self.name()], check=True, env=os.environ)
+                        subprocess.run([wmctrl_path, "-Fa", self.name()], check=True, env=os.environ)
                         return True
                     except subprocess.CalledProcessError:
                         log.debug("Could not find window title '{}' to bring it to front".format(self.name()))
