@@ -57,7 +57,7 @@ if sys.platform.startswith("win"):
 
     PRECONFIGURED_TELNET_CONSOLE_COMMANDS = {'Putty (normal standalone version)': 'putty_standalone.exe -telnet {host} {port} -loghost "{name}"',
                                              'KiTTY': r'kitty -title "{name}" telnet://{host} {port}',
-                                             'MobaXterm': r'"{}\Mobatek\MobaXterm Personal Edition\MobaXterm.exe" -newtab "telnet {{host}} {{port}}"'.format(program_files_x86),
+                                             'MobaXterm': r'"{}\Mobatek\MobaXterm Personal Edition\MobaXterm.exe" -newtab "title {{name}} & telnet {{host}} {{port}}"'.format(program_files_x86),
                                              'Royal TS V3': r'{}\code4ward.net\Royal TS V3\RTS3App.exe /connectadhoc:{{host}} /adhoctype:terminal /p:IsTelnetConnection="true" /p:ConnectionType="telnet;Telnet Connection" /p:Port="{{port}}" /p:Name="{{name}}"'.format(program_files),
                                              'Royal TS V5': r'"{}\Royal TS V5\RoyalTS.exe" /protocol:terminal /using:adhoc /uri:"{{host}}" /property:Port="{{port}}" /property:IsTelnetConnection="true" /property:Name="{{name}}"'.format(program_files_x86),
                                              'SuperPutty': r'SuperPutty.exe -telnet "{host} -P {port} -wt \"{name}\""',
@@ -168,7 +168,7 @@ else:
 
     if sys.platform.startswith("linux"):
         distro_name = distro.name()
-        if distro_name == "Debian" or distro_name == "Ubuntu" or distro_name == "LinuxMint":
+        if distro_name == "Debian" or distro_name == "Ubuntu" or distro_name == "Linux Mint":
             if shutil.which("mate-terminal"):
                 DEFAULT_TELNET_CONSOLE_COMMAND = PRECONFIGURED_TELNET_CONSOLE_COMMANDS["Mate Terminal"]
             else:
@@ -303,7 +303,6 @@ GENERAL_SETTINGS = {
     #"preferences_dialog_geometry": "",
     "debug_level": 0,
     "multi_profiles": False,
-    "hdpi": not sys.platform.startswith("linux"),
     "direct_file_upload": False,
     "symbol_theme": "Classic"
 }
